Welcome to PlasmaCalcs's documentation!
=======================================

**PlasmaCalcs** provides a consistent interface (in Python) for plasma calculations from any inputs.

See also `PlasmaCalcs on pypi <https://pypi.org/project/plasmacalcs/>`_ (install via ``pip install plasmacalcs``)

You can also find the latest version here: `https://gitlab.com/Sevans7/plasmacalcs <https://gitlab.com/Sevans7/plasmacalcs/>`_


.. note::

   Multiple jupyter notebook examples and guides are available via the links above (though they have not yet been added directly to these docs pages).


.. note::

   This project is still under active development.
   This note was last updated on Feb. 27, 2026.


.. toctree::
   :maxdepth: 2

   usage
   api
